pywr.recorders.FlowDurationCurveRecorder
========================================

.. currentmodule:: pywr.recorders

.. autoclass:: FlowDurationCurveRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FlowDurationCurveRecorder.after
      ~FlowDurationCurveRecorder.aggregated_value
      ~FlowDurationCurveRecorder.before
      ~FlowDurationCurveRecorder.finish
      ~FlowDurationCurveRecorder.load
      ~FlowDurationCurveRecorder.register
      ~FlowDurationCurveRecorder.reset
      ~FlowDurationCurveRecorder.setup
      ~FlowDurationCurveRecorder.to_dataframe
      ~FlowDurationCurveRecorder.unregister
      ~FlowDurationCurveRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FlowDurationCurveRecorder.agg_func
      ~FlowDurationCurveRecorder.children
      ~FlowDurationCurveRecorder.comment
      ~FlowDurationCurveRecorder.data
      ~FlowDurationCurveRecorder.epsilon
      ~FlowDurationCurveRecorder.fdc
      ~FlowDurationCurveRecorder.ignore_nan
      ~FlowDurationCurveRecorder.is_constraint
      ~FlowDurationCurveRecorder.is_objective
      ~FlowDurationCurveRecorder.model
      ~FlowDurationCurveRecorder.name
      ~FlowDurationCurveRecorder.node
      ~FlowDurationCurveRecorder.parents
      ~FlowDurationCurveRecorder.temporal_agg_func
   
   